"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEntityConfiguration = void 0;
const jsonWeb_1 = require("../jsonWeb");
const jsonWeb_2 = require("../jsonWeb");
const validate_1 = require("../utils/validate");
const entityConfigurationClaims_1 = require("./entityConfigurationClaims");
const entityConfigurationHeader_1 = require("./entityConfigurationHeader");
/**
 *
 * Create an entity configuration
 *
 * The signing callback will be called with the `header.kid` value in the `claims.jwks.keys` and a signed JWT will be returned
 *
 */
const createEntityConfiguration = (_a) => __awaiter(void 0, [_a], void 0, function* ({ header, signJwtCallback, claims, }) {
    // Validate the input
    const validatedHeader = (0, validate_1.validate)({
        schema: entityConfigurationHeader_1.entityConfigurationHeaderSchema,
        data: header,
        errorMessage: 'invalid header claims provided',
    });
    const validatedClaims = (0, validate_1.validate)({
        data: claims,
        schema: entityConfigurationClaims_1.entityConfigurationClaimsSchema,
        errorMessage: 'invalid payload claims provided',
    });
    // Create a signable input based on the header and payload
    const toBeSigned = (0, jsonWeb_1.createJwtSignableInput)(header, claims);
    // Fetch the key that will be used for signing
    const jwk = (0, jsonWeb_2.getUsedJsonWebKey)(validatedHeader, validatedClaims);
    // Call the signing callback so the user has to handle the crypto part
    const signature = yield signJwtCallback({ toBeSigned, jwk });
    // return a json web token based on the header, claims and associated signature
    return (0, jsonWeb_1.createJsonWebToken)(header, claims, signature);
});
exports.createEntityConfiguration = createEntityConfiguration;
//# sourceMappingURL=createEntityConfiguration.js.map