"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEntityStatement = void 0;
const jsonWeb_1 = require("../jsonWeb");
const validate_1 = require("../utils/validate");
const entityStatementClaims_1 = require("./entityStatementClaims");
const entityStatementHeader_1 = require("./entityStatementHeader");
/**
 *
 * Create an entity statement
 *
 * The signing callback will be called with the `header.kid` value in the `claims.jwks.keys` and a signed JWT will be returned
 *
 */
const createEntityStatement = (_a) => __awaiter(void 0, [_a], void 0, function* ({ signJwtCallback, claims, jwk, header = {
    typ: 'entity-statement+jwt',
    kid: jwk.kid,
}, }) {
    if (header.kid !== jwk.kid) {
        throw new Error(`key id in the header: '${header.kid}' does not match the key id in the JWK: '${jwk.kid}'`);
    }
    // Validate the input
    (0, validate_1.validate)({
        schema: entityStatementHeader_1.entityStatementHeaderSchema,
        data: header,
        errorMessage: 'invalid header claims provided',
    });
    (0, validate_1.validate)({
        schema: entityStatementClaims_1.entityStatementClaimsSchema,
        data: claims,
        errorMessage: 'invalid payload claims provided',
    });
    // Create a signable input based on the header and payload
    const toBeSigned = (0, jsonWeb_1.createJwtSignableInput)(header, claims);
    // Call the signing callback so the user has to handle the crypto part
    const signature = yield signJwtCallback({ toBeSigned, jwk });
    // return a json web token based on the header, claims and associated signature
    return (0, jsonWeb_1.createJsonWebToken)(header, claims, signature);
});
exports.createEntityStatement = createEntityStatement;
//# sourceMappingURL=createEntityStatement.js.map