"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.entityStatementClaimsSchema = void 0;
const constraints_1 = require("../constraints");
const jsonWeb_1 = require("../jsonWeb");
const metadata_1 = require("../metadata");
const trustMark_1 = require("../trustMark");
const utils_1 = require("../utils");
const zod_1 = require("zod");
exports.entityStatementClaimsSchema = zod_1.z
    .object({
    iss: zod_1.z.string(),
    sub: zod_1.z.string(),
    iat: utils_1.dateSchema,
    exp: utils_1.dateSchema,
    jwks: jsonWeb_1.jsonWebKeySetSchema,
    authority_hints: zod_1.z.array(zod_1.z.string().url()).optional(),
    metadata: metadata_1.metadataSchema.optional(),
    metadata_policy: metadata_1.metadataPolicySchema.optional(),
    constraints: constraints_1.constraintSchema.optional(),
    crit: zod_1.z.array(zod_1.z.string()).optional(),
    metadata_policy_crit: zod_1.z.array(zod_1.z.string()).optional(),
    trust_marks: zod_1.z.array(trustMark_1.trustMarkSchema).optional(),
    trust_mark_issuers: trustMark_1.trustMarkIssuerSchema.optional(),
    trust_mark_owners: trustMark_1.trustMarkOwnerSchema.optional(),
    source_endpoint: zod_1.z.string().url().optional(),
})
    .superRefine((data, ctx) => {
    const keyIds = data.jwks.keys.map((key) => key.kid);
    if (keyIds.some((key, i) => keyIds.indexOf(key) !== i)) {
        ctx.addIssue({
            code: 'custom',
            message: 'keys include duplicate key ids',
            path: ['jwks', 'keys'],
        });
    }
    return data;
});
//# sourceMappingURL=entityStatementClaims.js.map