"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchEntityStatement = void 0;
const entityConfiguration_1 = require("../entityConfiguration");
const verifyJsonWebToken_1 = require("../jsonWeb/verifyJsonWebToken");
const utils_1 = require("../utils");
const validate_1 = require("../utils/validate");
const entityStatementJwt_1 = require("./entityStatementJwt");
const fetchEntityStatement = (_a) => __awaiter(void 0, [_a], void 0, function* ({ sub, verifyJwtCallback, iss, endpoint, issEntityConfiguration, }) {
    const issEntityConfigurationClaims = issEntityConfiguration !== null && issEntityConfiguration !== void 0 ? issEntityConfiguration : (yield (0, entityConfiguration_1.fetchEntityConfiguration)({ entityId: iss, verifyJwtCallback }));
    const fetchEndpoint = endpoint !== null && endpoint !== void 0 ? endpoint : issEntityConfigurationClaims.source_endpoint;
    if (!fetchEndpoint) {
        throw new Error('No fetch endpoint provided or in the issuer configuration');
    }
    const entityStatementJwt = yield utils_1.fetcher.get({
        url: fetchEndpoint,
        searchParams: { iss, sub },
        requiredContentType: 'application/entity-statement+jwt',
    });
    // Parse the JWT into its claims and header claims
    const { claims } = (0, validate_1.validate)({
        schema: entityStatementJwt_1.entityStatementJwtSchema,
        data: entityStatementJwt,
        errorMessage: 'fetched entity statement JWT is invalid',
    });
    yield (0, verifyJsonWebToken_1.verifyJwtSignature)({
        verifyJwtCallback,
        jwt: entityStatementJwt,
        jwks: issEntityConfigurationClaims.jwks,
    });
    return claims;
});
exports.fetchEntityStatement = fetchEntityStatement;
//# sourceMappingURL=fetchEntityStatement.js.map