"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchEntityStatementChain = void 0;
const ErrorCode_1 = require("../error/ErrorCode");
const OpenIdFederationError_1 = require("../error/OpenIdFederationError");
const fetchEntityStatement_1 = require("./fetchEntityStatement");
const fetchEntityStatementChain = (_a) => __awaiter(void 0, [_a], void 0, function* ({ verifyJwtCallback, entityConfigurations, }) {
    if (entityConfigurations.length === 0) {
        throw new OpenIdFederationError_1.OpenIdFederationError(ErrorCode_1.ErrorCode.Validation, 'Cannot establish a statement chain for zero entity configurations');
    }
    // Reverse the configurations as we have to fetch the entity configuration of the trust anchor first
    // A copy is done here as the reverse method  mutates in place
    const reversedConfigurations = [...entityConfigurations].reverse();
    const promises = [];
    for (let i = 0; i < reversedConfigurations.length; i++) {
        // Get the configuration of the issuer
        const configuration = reversedConfigurations[i];
        // Get the configuration of the subject, i.e. the next in the chain
        const subjectConfiguration = reversedConfigurations[i + 1];
        // If we have no subject configuration we have reached the leaf entity as the `configuration`
        if (!subjectConfiguration)
            continue;
        const fetchEndpoint = configuration === null || configuration === void 0 ? void 0 : configuration.source_endpoint;
        if (!fetchEndpoint) {
            throw new OpenIdFederationError_1.OpenIdFederationError(ErrorCode_1.ErrorCode.Validation, `No source endpoint found for configuration for: '${configuration === null || configuration === void 0 ? void 0 : configuration.sub}'`);
        }
        promises.push((0, fetchEntityStatement_1.fetchEntityStatement)({
            verifyJwtCallback,
            endpoint: fetchEndpoint,
            iss: configuration.iss,
            sub: subjectConfiguration.sub,
            issEntityConfiguration: configuration,
        }));
    }
    // The trust anchors (i.e. the last item of the list) entity configuration will be used instead of a statement issued by a superior
    return [entityConfigurations[entityConfigurations.length - 1], ...(yield Promise.all(promises))].reverse();
});
exports.fetchEntityStatementChain = fetchEntityStatementChain;
//# sourceMappingURL=fetchEntityStatementChain.js.map